@@ -41,11 +41,11 @@ class CircuitMap(dict):
     def get_humanname(self, circuitname):
         """Return human-readable name for `circuitname`."""
         # lookup full name
-        humanname = self._map.get(circuitname, None)
+        humanname = self.get(circuitname, None)
         # loopup basename
         if humanname is None and "." in circuitname:
             basename, suffix = circuitname.split(".")
-            humanname = self._map.get(basename, None)
+            humanname = self.get(basename, None)
             if humanname is not None:
                 humanname = f"{humanname}#{suffix}"
         # use circuitname as default
